@@ -1,7 +1,10 @@
+import os
 import json
 import requests
 from urllib.parse import urlparse, parse_qs
 import configparser
+from datetime import date
+import pandas as pd
 
 
 def get_ms_config(ini_file, tgt_svc):
@@ -26,13 +29,15 @@ def getToken(base_url, params):
     url = base_url + 'token'
     r = requests.post(url, data=body, headers=headers)
     # print (r.json())
+    with open('response_token_body.json', 'w') as outfile:
+        json.dump(r.json(), outfile, ensure_ascii=False)
     access_token = r.json().get("access_token")
     print('{url} 请求响应时间：{used_time}, access_token={access_token}' \
           .format(url=url, used_time=r.elapsed.total_seconds(), access_token=access_token))
     return access_token
 
 
-def getData(access_token, url):
+def getData(access_token, url, save_res_to_file=False):
     headers = {
         'Content-type': 'application/json',
         'X-ENP-AUTH': access_token
@@ -43,6 +48,9 @@ def getData(access_token, url):
     if r.status_code != requests.codes.ok:
         print('erorr:')
         print(r.text)
+    if save_res_to_file:
+        with open('response_body.json', 'w') as outfile:
+            json.dump(r.json(), outfile, ensure_ascii=False)
     data = r.json().get('data')
     result = []
     for record in data:
@@ -56,12 +64,12 @@ def getData(access_token, url):
 
 
 # 获取数据湖数据的funcation
-def get_datalake_data(tgt_svc, api_path, load_all=False):
+def get_datalake_data(tgt_svc, api_path, load_all=False, save_res_to_file=False):
     base_url, token_params = get_ms_config('envision.ini', tgt_svc)
     access_token = getToken(base_url, token_params)
     url = base_url + api_path
     result = []
-    result, next_link = getData(access_token, url)
+    result, next_link = getData(access_token, url, save_res_to_file)
     while load_all and next_link != None:
         data, next_link = getData(access_token, next_link)
         result = result + data
@@ -72,6 +80,7 @@ def get_datalake_data(tgt_svc, api_path, load_all=False):
 def get_proxy_api_data(tgt_svc, api_path, return_data_path=None):
     base_url, token_params = get_ms_config('envision.ini', tgt_svc)
     access_token = getToken(base_url, token_params)
+    #print('access_token:'+access_token)
     url = base_url + api_path
     headers = {
         'Content-type': 'application/json',
@@ -88,7 +97,7 @@ def get_proxy_api_data(tgt_svc, api_path, return_data_path=None):
     return result
 
 
-def post_to_datalake_data_from_ex_server(access_token, url, body={}):
+def post_to_datalake_data_from_ex_server(access_token, url, body={}, save_res_to_file=False):
     headers = {
         'Content-type': 'application/json',
         'X-ENP-AUTH': access_token
@@ -100,6 +109,9 @@ def post_to_datalake_data_from_ex_server(access_token, url, body={}):
     if r.status_code != requests.codes.ok:
         print('erorr:')
         print(r.text)
+    if save_res_to_file:
+        with open('response_body.json', 'w') as outfile:
+            json.dump(r.json(), outfile, ensure_ascii=False)
     data = r.json().get('data')
     result = []
     for record in data:
@@ -113,9 +125,10 @@ def post_to_datalake_data_from_ex_server(access_token, url, body={}):
 
 
 # 获取挂接服务数据的function
-def get_datalake_data_from_ex_server(tgt_svc, prnName, lakeTableName, body={}, load_all=False):
+def get_datalake_data_from_ex_server(tgt_svc, prnName, lakeTableName, body={}, load_all=False, save_res_to_file=False):
     base_url, token_params = get_ms_config('envision.ini', tgt_svc)
     access_token = getToken(base_url, token_params)
+    #print('access_token:' +access_token)
     url = base_url + 'it/lightning/exsap/api/oa/tables?prnName={prnName}&lakeTableName={lakeTableName}' \
         .format(prnName=prnName, lakeTableName=lakeTableName)
     headers = {
@@ -124,7 +137,7 @@ def get_datalake_data_from_ex_server(tgt_svc, prnName, lakeTableName, body={}, l
     }
 
     result = []
-    result, next_link = post_to_datalake_data_from_ex_server(access_token, url, body)
+    result, next_link = post_to_datalake_data_from_ex_server(access_token, url, body, save_res_to_file)
     while load_all and next_link != None:
         print('next_link=' + next_link)
         qs = parse_qs(urlparse(next_link).query)
@@ -134,3 +147,56 @@ def get_datalake_data_from_ex_server(tgt_svc, prnName, lakeTableName, body={}, l
         data, next_link = post_to_datalake_data_from_ex_server(access_token, ex_next_link)
         result = result + data
     return result
+
+
+# 调用微服务
+def post_to_ms(tgt_svc, api_path, body={}, save_res_to_file=False):
+    base_url, token_params = get_ms_config('envision.ini', tgt_svc)
+    access_token = getToken(base_url, token_params)
+    url = base_url + api_path
+    headers = {
+        'Content-type': 'application/json',
+        'X-ENP-AUTH': access_token
+    }
+    # print (url)
+    body = json.dumps(body)
+    r = requests.post(url, headers=headers, data=body)
+    print('{0} 请求响应时间：{1}'.format(url, r.elapsed.total_seconds()))
+    if r.status_code != requests.codes.ok:
+        print('erorr:')
+        print(r.text)
+    if save_res_to_file:
+        with open('response_body.json', 'w') as outfile:
+            json.dump(r.json(), outfile, ensure_ascii=False)
+    return r.json()
+
+
+def put_to_ms(tgt_svc, api_path, body={}, save_res_to_file=False):
+    base_url, token_params = get_ms_config('envision.ini', tgt_svc)
+    access_token = getToken(base_url, token_params)
+    url = base_url + api_path
+    headers = {
+        'Content-type': 'application/json',
+        'X-ENP-AUTH': access_token
+    }
+    # print (url)
+    body = json.dumps(body)
+    r = requests.put(url, headers=headers, data=body)
+    print('{0} 请求响应时间：{1}'.format(url, r.elapsed.total_seconds()))
+    if r.status_code != requests.codes.ok:
+        print('erorr:')
+        print(r.text)
+    if save_res_to_file:
+        with open('response_body.json', 'w') as outfile:
+            json.dump(r.json(), outfile, ensure_ascii=False)
+    return r.json()
+
+
+def save_json_data(records, to_file_name):
+    df = pd.DataFrame(records)
+    data_dir = './data/{}'.format(str(date.today()))
+    os.makedirs(data_dir, exist_ok=True)
+    df.to_json('{}/{}.json'.format(data_dir, to_file_name), orient='records', force_ascii=False)
+    print('save {} to {}'.format(to_file_name, '{}/{}.json'.format(data_dir, to_file_name)))
+    df.to_excel('{}/{}.xlsx'.format(data_dir, to_file_name), index=False)
+    print('save {} to {}'.format(to_file_name, '{}/{}.xlsx'.format(data_dir, to_file_name)))
